@@ -68,6 +68,22 @@ inline KTextEditor::DefaultStyle textStyleToDefaultStyle(const KSyntaxHighlighti
     return static_cast<KTextEditor::DefaultStyle>(textStyle);
 }
 
+/**
+ * convert the theme/schema name from KTextEditor => KSyntaxHighlighting.
+ * NOTE: some themes of KTextEditor don't exist in KSyntaxHighlighting
+ */
+inline QString convertThemeName(const QString &schema)
+{
+    if (schema == QLatin1String("Normal")) {
+        return QStringLiteral("Default");
+    } else if (schema == QLatin1String("Solarized (light)")) {
+        return QStringLiteral("Solarized Light");
+    } else if (schema == QLatin1String("Solarized (dark)")) {
+        return QStringLiteral("Solarized Dark");
+    }
+    return schema;
+}
+
 }
 //END
 
@@ -81,9 +97,15 @@ KateHighlighting::KateHighlighting(const KSyntaxHighlighting::Definition &def)
     iSection = def.translatedSection();
 
     /**
-     * handle the "no highlighting" case
+     * get all included definitions, e.g. PHP for HTML highlighting
      */
-    if (!def.isValid()) {
+    auto definitions = def.includedDefinitions();
+
+    /**
+     * handle the "no highlighting" case
+     * it's possible to not have any defintions with malformed file
+     */
+    if (!def.isValid() || (definitions.isEmpty() && def.formats().isEmpty())) {
         // dummy properties + formats
         m_properties.resize(1);
         m_propertiesForFormat.push_back(&m_properties[0]);
@@ -110,11 +132,6 @@ KateHighlighting::KateHighlighting(const KSyntaxHighlighting::Definition &def)
      */
     setDefinition(def);
 
-    /**
-     * get all included definitions, e.g. PHP for HTML highlighting
-     */
-    auto definitions = definition().includedDefinitions();
-
     /**
      * first: handle only really included definitions
      */
@@ -251,7 +268,9 @@ void KateHighlighting::applyFormat(int offset, int length, const KSyntaxHighligh
 {
     // WE ATM assume ascending offset order
     Q_ASSERT(m_textLineToHighlight);
-    Q_ASSERT(format.isValid());
+    if (!format.isValid()) {
+        return;
+    }
 
     // get internal attribute, must exist
     const auto it = m_formatsIdToIndex.find(format.id());
@@ -267,7 +286,7 @@ void KateHighlighting::applyFolding(int offset, int length, KSyntaxHighlighting:
     Q_ASSERT(m_textLineToHighlight);
     Q_ASSERT(region.isValid());
     const int foldingValue = (region.type() == KSyntaxHighlighting::FoldingRegion::Begin) ? int(region.id()) : -int(region.id());
-    m_textLineToHighlight->addFolding(offset + (region.type() == KSyntaxHighlighting::FoldingRegion::Begin) ? 0 : length, foldingValue);
+    m_textLineToHighlight->addFolding(offset + ((region.type() == KSyntaxHighlighting::FoldingRegion::Begin) ? 0 : length), foldingValue);
 
     /**
      * for each end region, decrement counter for that type, erase if count reaches 0!
@@ -296,7 +315,7 @@ void KateHighlighting::getKateExtendedAttributeList(const QString &schema, QVect
     KConfigGroup config(cfg ? cfg : KateHlManager::self()->getKConfig(),
                         QLatin1String("Highlighting ") + iName + QLatin1String(" - Schema ") + schema);
 
-    list = attributesForDefinition();
+    list = attributesForDefinition(schema);
 
     foreach (KTextEditor::Attribute::Ptr p, list) {
         Q_ASSERT(p);
@@ -304,7 +323,7 @@ void KateHighlighting::getKateExtendedAttributeList(const QString &schema, QVect
         QStringList s = config.readEntry(p->name(), QStringList());
 
 //    qCDebug(LOG_KTE)<<p->name<<s.count();
-        if (s.count() > 0) {
+        if (!s.isEmpty()) {
 
             while (s.count() < 10) {
                 s << QString();
@@ -395,7 +414,7 @@ void KateHighlighting::setKateExtendedAttributeList(const QString &schema, QVect
         settings << (p->hasProperty(QTextFormat::FontWeight) ? (p->fontBold() ? QStringLiteral("1") : QStringLiteral("0")) : (writeDefaultsToo ? (a->fontBold() ? QStringLiteral("1") : QStringLiteral("0")) : QString()));
         settings << (p->hasProperty(QTextFormat::FontItalic) ? (p->fontItalic() ? QStringLiteral("1") : QStringLiteral("0")) : (writeDefaultsToo ? (a->fontItalic() ? QStringLiteral("1") : QStringLiteral("0")) : QString()));
         settings << (p->hasProperty(QTextFormat::FontStrikeOut) ? (p->fontStrikeOut() ? QStringLiteral("1") : QStringLiteral("0")) : (writeDefaultsToo ? (a->fontStrikeOut() ? QStringLiteral("1") : QStringLiteral("0")) : QString()));
-        settings << (p->hasProperty(QTextFormat::FontUnderline) ? (p->fontUnderline() ? QStringLiteral("1") : QStringLiteral("0")) : (writeDefaultsToo ? (a->fontUnderline() ? QStringLiteral("1") : QStringLiteral("0")) : QString()));
+        settings << (p->hasProperty(QTextFormat::TextUnderlineStyle) ? (p->fontUnderline() ? QStringLiteral("1") : QStringLiteral("0")) : (writeDefaultsToo ? (a->fontUnderline() ? QStringLiteral("1") : QStringLiteral("0")) : QString()));
         settings << (p->hasProperty(QTextFormat::BackgroundBrush) ? QString::number(p->background().color().rgb(), 16) : ((writeDefaultsToo && a->hasProperty(QTextFormat::BackgroundBrush)) ? QString::number(a->background().color().rgb(), 16) : QString()));
         settings << (p->hasProperty(SelectedBackground) ? QString::number(p->selectedBackground().color().rgb(), 16) : ((writeDefaultsToo && a->hasProperty(SelectedBackground)) ? QString::number(a->selectedBackground().color().rgb(), 16) : QString()));
         settings << (p->hasProperty(QTextFormat::FontFamily) ? (p->fontFamily()) : (writeDefaultsToo ? a->fontFamily() : QString()));
@@ -502,23 +521,34 @@ void KateHighlighting::clearAttributeArrays()
     m_attributeArrays.clear();
 }
 
-QVector<KTextEditor::Attribute::Ptr> KateHighlighting::attributesForDefinition()
+QVector<KTextEditor::Attribute::Ptr> KateHighlighting::attributesForDefinition(const QString &schema)
 {
-     /**
+    /**
+     * get the KSyntaxHighlighting theme from the chosen schema.
+     * NOTE: if the theme isn't valid for KSyntaxHighlighting, an empty/invalid theme will be used.
+     * For example, the "KDE" and "Vim (dark)" themes don't exist in KSyntaxHighlighting.
+     */
+    KSyntaxHighlighting::Theme currentTheme = KateHlManager::self()->repository().theme(convertThemeName(schema));
+
+    /**
      * create list of all known things
      */
     QVector<KTextEditor::Attribute::Ptr> array;
     for (const auto &format : m_formats) {
         /**
-         * FIXME: atm we just set some theme here for later color generation
+         * atm we just set the current chosen theme here for later color generation
          */
-        setTheme(KateHlManager::self()->repository().defaultTheme(KSyntaxHighlighting::Repository::LightTheme));
+        setTheme(currentTheme);
 
         /**
          * create a KTextEditor attribute matching the given format
          */
         KTextEditor::Attribute::Ptr newAttribute(new KTextEditor::Attribute(nameForAttrib(array.size()), textStyleToDefaultStyle(format.textStyle())));
 
+        /**
+         * NOTE: if "theme()" returns an empty theme, only the
+         * attribute styles set in the XML files will be applied here
+         */
         if (format.hasTextColor(theme())) {
             newAttribute->setForeground(format.textColor(theme()));
             newAttribute->setSelectedForeground(format.selectedTextColor(theme()));
